@@ -26,19 +26,19 @@ This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
 =head2 closed
 
-  has closed : ro byte;
+C<has closed : ro byte;>
 
 The file stream is closed.
 
-=head2 no_need_free
+=head2 no_close
 
-  has no_need_free : ro byte;
+C<has no_close : ro byte;>
 
-The file stream is not needed to be freed.
+If this field is set to a true value, the file stream must not be closed.
 
 =head1 Instance Methods
 
-  method DESTROY : void ();
+C<method DESTROY : void ();>
 
 The destructor.
 
