@@ -10,6 +10,11 @@
 #include <errno.h>
 #include <assert.h>
 
+#if defined(_WIN32)
+#else
+  #include <sys/un.h>
+#endif
+
 static const char* FILE_NAME = "Sys/Socket.c";
 
 int32_t SPVM__Sys__Socket__socket_errno(SPVM_ENV* env, SPVM_VALUE* stack) {
@@ -77,15 +82,15 @@ int32_t SPVM__Sys__Socket__ntohs(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-  int32_t e = 0;
+  int32_t error_id = 0;
   
-  int32_t InvalidNetworkAddress = env->get_basic_type_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t InvalidNetworkAddress = env->get_basic_type_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   void* obj_cp = stack[0].oval;
   
   if (!obj_cp) {
-    return env->die(env, stack, "The $cp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$cp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* cp = env->get_chars(env, stack, obj_cp);
@@ -93,7 +98,7 @@ int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_inp = stack[1].oval;
   
   if (!obj_inp) {
-    return env->die(env, stack, "The $inp must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$inp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct in_addr* st_in_addr = env->get_pointer(env, stack, obj_inp);
@@ -105,7 +110,7 @@ int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 
   if (status == 0) {
-    env->die(env, stack, "The got address is not a valid network address", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The got address is not a valid network address.", __func__, FILE_NAME, __LINE__);
     return InvalidNetworkAddress;
   }
   else if (status == -1) {
@@ -123,7 +128,7 @@ int32_t SPVM__Sys__Socket__inet_ntoa(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_in = stack[0].oval;
   
   if (!obj_in) {
-    return env->die(env, stack, "The $in address must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$in address must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct in_addr* in = env->get_pointer(env, stack, obj_in);
@@ -150,27 +155,27 @@ int32_t SPVM__Sys__Socket__inet_ntoa(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
-  int32_t InvalidNetworkAddress = env->get_basic_type_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t InvalidNetworkAddress = env->get_basic_type_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
 
   int32_t In_addr = env->get_basic_type_id(env, stack, "Sys::Socket::In_addr");
-  if (e) { return e; }
+  if (error_id) { return error_id; }
 
   int32_t In6_addr = env->get_basic_type_id(env, stack, "Sys::Socket::In6_addr");
-  if (e) { return e; }
+  if (error_id) { return error_id; }
 
   int32_t af = stack[0].ival;
   
   if (!(af == AF_INET || af == AF_INET6)) {
-    return env->die(env, stack, "The $af must be AF_INET or AF_INET6", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_src = stack[1].oval;
   
   if (!obj_src) {
-    return env->die(env, stack, "The $src must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$src must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* src = env->get_chars(env, stack, obj_src);
@@ -178,21 +183,21 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_dst = stack[2].oval;
   
   if (!obj_dst) {
-    return env->die(env, stack, "The $dst must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dst must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   if (af == AF_INET) {
     if (!env->is_type_by_name(env, stack, obj_dst, "Sys::Socket::In_addr", 0)) {
-      return env->die(env, stack, "The $dst must be the Sys::Socket::In_addr class", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "$dst must be the Sys::Socket::In_addr class.", __func__, FILE_NAME, __LINE__);
     }
   }
   else if (af == AF_INET6) {
     if (!env->is_type_by_name(env, stack, obj_dst, "Sys::Socket::In6_addr", 0)) {
-      return env->die(env, stack, "The $dst must be the Sys::Socket::In6_addr class", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "$dst must be the Sys::Socket::In6_addr class.", __func__, FILE_NAME, __LINE__);
     }
   }
   else {
-    return env->die(env, stack, "The type of the $dst is invalid", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The type of $dst is invalid.", __func__, FILE_NAME, __LINE__);
   }
   
   void* dst = env->get_pointer(env, stack, obj_dst);
@@ -200,7 +205,7 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = inet_pton(af, src, dst);
   
   if (status == 0) {
-    env->die(env, stack, "The got address is not a valid network address", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The got address is not a valid network address.", __func__, FILE_NAME, __LINE__);
     return InvalidNetworkAddress;
   }
   else if (status == -1) {
@@ -219,20 +224,20 @@ int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t af = stack[0].ival;
 
   if (!(af == AF_INET || af == AF_INET6)) {
-    return env->die(env, stack, "The $af must be AF_INET or AF_INET6", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
   }
   
   // The input address
   void* obj_src = stack[1].oval;
   if (!obj_src) {
-    return env->die(env, stack, "The $src must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$src must be defined.", __func__, FILE_NAME, __LINE__);
   }
   void* src = env->get_pointer(env, stack, obj_src);
   
   // The output address
   void* obj_dst = stack[2].oval;
   if (!obj_dst) {
-    return env->die(env, stack, "The $dst must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dst must be defined.", __func__, FILE_NAME, __LINE__);
   }
   char* dst = (char*)env->get_chars(env, stack, obj_dst);
   
@@ -272,14 +277,14 @@ int32_t SPVM__Sys__Socket__socket(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 
-int32_t SPVM__Sys__Socket__connect_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Sys__Socket__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t sockfd = stack[0].ival;
   
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "The $addr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -288,20 +293,13 @@ int32_t SPVM__Sys__Socket__connect_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = connect(sockfd, addr, addrlen);
   
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t status = SPVM__Sys__Socket__connect_raw(env, stack);
-  
   if (status == -1) {
     env->die(env, stack, "[System Error]connect failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
+  stack[0].ival = status;
+  
   return 0;
 }
 
@@ -312,7 +310,7 @@ int32_t SPVM__Sys__Socket__bind(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "The $addr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -338,7 +336,7 @@ int32_t SPVM__Sys__Socket__accept(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "The $addr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -386,7 +384,7 @@ int32_t SPVM__Sys__Socket__recv(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
@@ -398,7 +396,7 @@ int32_t SPVM__Sys__Socket__recv(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t buf_offset = stack[4].ival;
   if (!(len <= buf_length - buf_offset)) {
-    return env->die(env, stack, "The $len must be less than the length of the $buf - the $buf_offset", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$len must be less than the length of $buf - $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t bytes_length = recv(sockfd, buf + buf_offset, len, flags);
@@ -420,7 +418,7 @@ int32_t SPVM__Sys__Socket__send(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* buf = env->get_chars(env, stack, obj_buf);
@@ -432,7 +430,7 @@ int32_t SPVM__Sys__Socket__send(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t buf_offset = stack[4].ival;
   if (!(len <= buf_length - buf_offset)) {
-    return env->die(env, stack, "The $len must be less than the length of the $buf - the $buf_offset", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$len must be less than the length of $buf - $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t bytes_length = send(sockfd, buf + buf_offset, len, flags);
@@ -454,7 +452,7 @@ int32_t SPVM__Sys__Socket__getpeername(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "The $addr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -484,7 +482,7 @@ int32_t SPVM__Sys__Socket__getsockname(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[1].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "The $addr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -509,7 +507,7 @@ int32_t SPVM__Sys__Socket__getsockname(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "socketpair is not supported on this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "socketpair is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -522,14 +520,14 @@ int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_sv = stack[3].oval;
   
   if (!obj_sv) {
-    return env->die(env, stack, "The $sv must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$sv must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t* sv = env->get_elems_int(env, stack, obj_sv);
   int32_t sv_length = env->length(env, stack, obj_sv);
   
   if (!(sv_length >= 2)) {
-    return env->die(env, stack, "The length of the $sv must be greater than or equal to 2", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length of $sv must be greater than or equal to 2.", __func__, FILE_NAME, __LINE__);
   }
   
   int int_sv[2];
@@ -560,17 +558,17 @@ int32_t SPVM__Sys__Socket__setsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_optval = stack[3].oval;
   char* optval = NULL;
   if (!obj_optval) {
-    return env->die(env, stack, "The $optval must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
   }
   optval = (char*)env->get_chars(env, stack, obj_optval);
   int32_t optval_length = env->length(env, stack, obj_optval);
 
   socklen_t optlen = stack[4].ival;
   if (!(optlen >= 0)) {
-    env->die(env, stack, "The $optlen must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "$optlen must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   if (!(optlen <= optval_length)) {
-    env->die(env, stack, "The $optlen must be less than or equal to the length of the $optval", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "$optlen must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = setsockopt(sockfd, level, optname, optval, optlen);
@@ -613,17 +611,17 @@ int32_t SPVM__Sys__Socket__getsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_optval = stack[3].oval;
   char* optval = NULL;
   if (!obj_optval) {
-    return env->die(env, stack, "The $optval must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
   }
   optval = (char*)env->get_chars(env, stack, obj_optval);
   int32_t optval_length = env->length(env, stack, obj_optval);
 
   int32_t* optlen_ref = stack[4].iref;
   if (!(*optlen_ref >= 0)) {
-    env->die(env, stack, "The referred value of the $optlen_ref must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The referred value of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   if (!(*optlen_ref <= optval_length)) {
-    env->die(env, stack, "The referred value of the $optlen_ref must be less than or equal to the length of the $optval", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "The referred value of $optlen_ref must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
   }
   
   socklen_t socklen_t_optlen = *optlen_ref;
@@ -684,15 +682,15 @@ int32_t SPVM__Sys__Socket__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__close(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Sys__Socket__closesocket(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if !defined(_WIN32)
+  env->die(env, stack, "[Not Supported]closesocket is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
   int32_t s = stack[0].ival;
   
-#if defined(_WIN32)
   int32_t status = closesocket(s);
-#else
-  int32_t status = close(s);
-#endif
-
+  
   if (!(status == 0)) {
     env->die(env, stack, "[System Error]close failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
@@ -701,6 +699,7 @@ int32_t SPVM__Sys__Socket__close(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = status;
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__Socket__gai_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
@@ -723,8 +722,8 @@ int32_t SPVM__Sys__Socket__gai_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__getaddrinfo_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t e = 0;
+int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
+  int32_t error_id = 0;
   
   void* obj_node = stack[0].oval;
   
@@ -749,11 +748,11 @@ int32_t SPVM__Sys__Socket__getaddrinfo_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_res_array = stack[3].oval;
   if (!obj_res_array) {
-    return env->die(env, stack, "The $res_array must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$res_array must be defined.", __func__, FILE_NAME, __LINE__);
   }
   int32_t res_array_length = env->length(env, stack, obj_res_array);
   if (!(res_array_length >= 1)) {
-    return env->die(env, stack, "The length of the $res_array must be greater than or equal to 1", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length of $res_array must be greater than or equal to 1.", __func__, FILE_NAME, __LINE__);
   }
   
   struct addrinfo *res = NULL;
@@ -762,24 +761,11 @@ int32_t SPVM__Sys__Socket__getaddrinfo_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   if (status == 0) {
     int32_t fields_length = 1;
-    void* obj_res = env->new_pointer_object_by_name(env, stack, "Sys::Socket::AddrinfoLinkedList", res, &e, __func__, FILE_NAME, __LINE__);
-    if (e) { return e; }
+    void* obj_res = env->new_pointer_object_by_name(env, stack, "Sys::Socket::AddrinfoLinkedList", res, &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
     env->set_elem_object(env, stack, obj_res_array, 0, obj_res);
   }
-  
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t e = 0;
-  
-  e = SPVM__Sys__Socket__getaddrinfo_raw(env, stack);
-  if (e) { return e; }
-  
-  int32_t status = stack[0].ival;
-  if (!(status == 0)) {
+  else {
     stack[0].ival = status;
     SPVM__Sys__Socket__gai_strerror(env, stack);
     void* obj_gai_strerror = stack[0].oval;
@@ -788,16 +774,19 @@ int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
+  stack[0].ival = status;
+  
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__getnameinfo_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t e = 0;
+int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
   
   void* obj_sa = stack[0].oval;
   
   if (!obj_sa) {
-    return env->die(env, stack, "The $sa must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$sa must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* sa = env->get_pointer(env, stack, obj_sa);
@@ -824,18 +813,6 @@ int32_t SPVM__Sys__Socket__getnameinfo_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = getnameinfo(sa, salen, host, hostlen, serv, servlen, flags);
   
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t e = 0;
-  
-  e = SPVM__Sys__Socket__getnameinfo_raw(env, stack);
-  if (e) { return e; }
-  
-  int32_t status = stack[0].ival;
   if (!(status == 0)) {
     stack[0].ival = status;
     SPVM__Sys__Socket__gai_strerror(env, stack);
@@ -845,12 +822,14 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
+  stack[0].ival = status;
+  
   return 0;
 }
 
 int32_t SPVM__Sys__Socket__sockatmark(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-    env->die(env, stack, "[Not Supported]sockatmark is not supported on this system(defined(_WIN32))", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[Not Supported]sockatmark is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -876,7 +855,7 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* buf = env->get_chars(env, stack, obj_buf);
@@ -888,7 +867,7 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[4].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "The $addr must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -906,3 +885,57 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   return 0;
 }
+
+int32_t SPVM__Sys__Socket__to_family_sockaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
+  int32_t error_id = 0;
+  
+  void* obj_addr = stack[0].oval;
+  
+  if (!obj_addr) {
+    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
+  
+  int32_t sa_family = addr->sa_family;
+  
+  void* obj_addr_child = NULL;
+  
+  switch (sa_family) {
+    case AF_INET: {
+      struct sockaddr_in* addr_in = env->new_memory_block(env, stack, sizeof(struct sockaddr_in));
+      memcpy(addr_in, addr, sizeof(struct sockaddr_in));
+      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In", addr_in, &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+      
+      break;
+    }
+    case AF_INET6: {
+      struct sockaddr_in6* addr_in6 = env->new_memory_block(env, stack, sizeof(struct sockaddr_in6));
+      memcpy(addr_in6, addr, sizeof(struct sockaddr_in6));
+      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In6", addr_in6, &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+      
+      break;
+    }
+    case AF_UNIX: {
+#if defined(_WIN32)
+      env->die(env, stack, "AF_UNIX is not supported in this system(defined(_WIN32))", sa_family, __func__, FILE_NAME, __LINE__);
+      return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+      struct sockaddr_un* addr_un = env->new_memory_block(env, stack, sizeof(struct sockaddr_un));
+      memcpy(addr_un, addr, sizeof(struct sockaddr_un));
+      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::Un", addr_un, &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+#endif
+      break;
+    }
+    default: {
+      return env->die(env, stack, "The address family %d is not available.", sa_family, __func__, FILE_NAME, __LINE__);
+    }
+  }
+  
+  stack[0].oval = obj_addr_child;
+  
+  return 0;
+}
